Description Usage Arguments Value See Also
: Stochastically determined deaths at each time period of the simulation
1 | deaths(dat, at)
|
dat |
|
at |
This function returns the dat object recording for each time step at, the number of susceptible deaths
ds.flow, and infected deaths di.flow
broken down into on treatment and lost to follow-up deaths dtrt.flow and dlfu.flow (therefore, 'di.flow = dtrt.flow + dlfu.flow')
This function is used by:
run_abm
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.