run_abm: run_abm.R

Description Usage Arguments Value See Also

View source: R/run_abm.R

Description

Run the different functions to get the full simulation of a cohort of patients, in the baseline scenario (standard of care) and with the different intervention scenarios

Usage

1
2
3
4
5
6
7
8
run_abm(
  init,
  param,
  scenario_simulation,
  intervention_start = 0,
  prop_male,
  nsteps = 52 * 5
)

Arguments

init

A list including the initial conditions of the simulation: prevalence of the infection, maximum span of infection considered, initial size of the cohort simulated

param

A list including the biological and intervention parameters, along with the age-sex-specific death rates

scenario_simulation

Character vector indicating which scenario is being considered for the simulation

intervention_start

A numeric value indicating at which time step the intervention starts (i.e. when the simulation starts using the intervention parameters over the baseline parameters) [default = 0]

prop_male

A numeric value indicating what share of the population is male This value is currently scraped from the UNAIDS indicators

n_steps

A numeric value indicating the duration of the intervention [default = 52*5], i.e. 5 years

Value

This function returns the dat object, recording the evolution of the attributes and epidemiological modules, for the duration of the simulation

See Also

This function is used by: run_simulations


grlurton/ImpactSimul documentation built on March 8, 2021, 12:05 a.m.