Description Usage Arguments Value See Also
: Stochastically determined which individuals are getting tested at every time step ‘at’
1 | test(dat, at, scenario)
|
dat |
|
at |
|
scenario |
scenario's name |
: This function returns the dat object with updated dxStat, txStat, and dxTime attributes
This function is used by:
run_abm
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.